@@ -67,7 +67,7 @@ os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"  # FATAL
 logging.getLogger("tensorflow").setLevel(logging.FATAL)
 
 
-class FGSM():
+class FGSM():  # pylint: disable=too-few-public-methods
     """Implements fast gradient sign method (FGSM) to create adversarial
     examples.
 
@@ -78,7 +78,7 @@ class FGSM():
         # Eps: Multiplier to ensure the perturbations are small.
         adv_x = image + eps*perturbations
 
-
+fake_output
     Attributes:
         model (keras.model): NN to fool.
         loss: Loss used to train model.
