@@ -224,7 +224,11 @@ class GAN():
         self.ckpt_manager = None
         self.checkpoint = None
 
-    def compile(self, optimizer="adam", lr_gen=1e-4, lr_disc=1e-4):
+    def compile(self,
+                optimizer="adam",
+                lr_gen=1e-4,
+                lr_disc=1e-4,
+                loss_scaling=False):
         """Defines the optimization part of the learning algorithm to our
         learning model.
 
@@ -234,10 +238,37 @@ class GAN():
             lr_disc (Float, optional): Learning rate discriminator.
                 Defaults to 1e4.
         """
-        # TODO: more optimizer
-        if optimizer == "adam":
+        if optimizer == "adadelta":
+            self.generator_optimizer = tf.keras.optimizers.Adadelta(lr_gen)
+            self.discriminator_optimizer = tf.keras.optimizers.Adadelta(
+                lr_disc)
+        elif optimizer == "adagrad":
+            self.generator_optimizer = tf.keras.optimizers.Adagrad(lr_gen)
+            self.discriminator_optimizer = tf.keras.optimizers.Adagrad(lr_disc)
+        elif optimizer == "adam":
             self.generator_optimizer = tf.keras.optimizers.Adam(lr_gen)
             self.discriminator_optimizer = tf.keras.optimizers.Adam(lr_disc)
+        elif optimizer == "adamax":
+            self.generator_optimizer = tf.keras.optimizers.Adamax(lr_gen)
+            self.discriminator_optimizer = tf.keras.optimizers.Adamax(lr_disc)
+        elif optimizer == "ftrl":
+            self.generator_optimizer = tf.keras.optimizers.Ftrl(lr_gen)
+            self.discriminator_optimizer = tf.keras.optimizers.Ftrl(lr_disc)
+        elif optimizer == "nadam":
+            self.generator_optimizer = tf.keras.optimizers.Nadam(lr_gen)
+            self.discriminator_optimizer = tf.keras.optimizers.Nadam(lr_disc)
+        elif optimizer == "rmsprop":
+            self.generator_optimizer = tf.keras.optimizers.RMSprop(lr_gen)
+            self.discriminator_optimizer = tf.keras.optimizers.RMSprop(lr_disc)
+        elif optimizer == "sgd":
+            self.generator_optimizer = tf.keras.optimizers.SGD(lr_gen)
+            self.discriminator_optimizer = tf.keras.optimizers.SGD(lr_disc)
+
+        if loss_scaling:
+            self.generator_optimizer = tf.keras.mixed_precision.LossScaleOptimizer(
+                self.generator_optimizer)
+            self.discriminator_optimizer = tf.keras.mixed_precision.LossScaleOptimizer(
+                self.discriminator_optimizer)
 
         if self.checkpoint is None:
             self.checkpoint = tf.train.Checkpoint(
