@@ -14,5 +14,7 @@
 # =============================================================================
 """Image detection models API"""
 from dnnlab.input_pipeline import img
+from dnnlab.input_pipeline import img_img
 from dnnlab.input_pipeline import yolo
 from dnnlab.input_pipeline.triplet_net import TripletDataset
+from dnnlab.input_pipeline.data_augmentation import YoloAugmentation
\ No newline at end of file
