@@ -16,4 +16,4 @@
 from dnnlab.layers.yolo_decoder import YOLODecoder
 from dnnlab.layers.se_block import SEBlock
 from dnnlab.layers.non_local_block import NonLocalBlock
-from dnnlab.layers.morph_layer import Morph2D
+from dnnlab.layers.morph_layer_hide import Morph2D
